@@ -7,7 +7,7 @@ from colorama import Fore
 
 from pettifogger.workflow.structure.env import Env
 from pettifogger.utils.configuration import get_global_configuration
-
+from pettifogger.utils.constants import GITHUB_BUILTIN_ENV_VARS
 
 class Step:
     def __init__(self, definition, context, index, parent_job_id, *args, **kwargs):
@@ -84,7 +84,11 @@ class Step:
                     has_errors = True
 
                 script_level_env_vars = {**script_level_env_vars, **new_script_level_env_vars}
-                command_env_vars = {**script_level_env_vars, **new_command_level_env_vars}
+                command_env_vars = {
+                    **script_level_env_vars,
+                    **new_command_level_env_vars,
+                    **{ key: "placeholder" for key in GITHUB_BUILTIN_ENV_VARS }
+                }
 
                 string_final_env_vars_list = ", ".join(command_env_vars.keys())
                 detected_env_vars = Env.ENV_VAR_REGEX.findall(line)
@@ -94,7 +98,8 @@ class Step:
                     if item not in command_env_vars:
                         has_errors = True
                         logger.error(
-                            f"Could not find variable '{item}' from environment variables ({string_final_env_vars_list}) on line '{line}'",
+                            f"Could not find variable '{item}' from environment variables or from Github Actions "
+                            f"builtin environment variables ({string_final_env_vars_list}) on line '{line}'",
                             source_id=self.log_source_id
                         )
                     elif str(command_env_vars[item]).strip() == "":
